.. _Analysis:

========
Analysis
========

.. toctree::
   :maxdepth: 2

   analysis/Introduction.rst
   analysis/Methods.rst
   analysis/Results.rst
   analysis/Discussion.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


